#
# spec file for package ghc-hslua-module-path
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-module-path
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.1.1
Release:        1.6
Summary:        Lua module to work with file paths
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-hslua-core-devel
BuildRequires:  ghc-hslua-core-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-hslua-packaging-devel
BuildRequires:  ghc-hslua-packaging-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-lua-devel
BuildRequires:  ghc-tasty-lua-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Lua module to work with file paths in a platform independent way.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-path to version 1.1.1.
  [#]# hslua-module-path-1.1.1
  Released 2024-01-18.
  - Relaxed upper bound for text, and filepath,
    allowing text-2.1, filepath-1.5.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-path to version 1.1.0.
  [#]# hslua-module-path-1.1.0
  Released 2023-03-13.
  - Update to hslua-2.3; this includes the addition of type
    initializers to the module and type specifiers to the fields.
  - Fixed tests for `make_relative` on Windows.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Aug 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-path to version 1.0.3.
  [#]# hslua-module-path-1.0.3
  Released 2022-08-19.
  - Fixed `make_relative` for longer base paths: Ensure that the
    function produces correct results in cases where the root
    (base) path has more components than the path that should be
    made relative.
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-path to version 1.0.2.
  [#]# hslua-module-path-1.0.2
  Released 2022-02-19.
  - Adjusted package bounds, for hslua-core, hslua-marshalling,
    and hslua-packaging.
* Sun Jan 30 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-path to version 1.0.1 revision 1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-module-path-1.0.1/src/CHANGELOG.md
* Mon Nov  1 2021 psimons@suse.com
- Update hslua-module-path to version 1.0.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Tue Mar  9 2021 psimons@suse.com
- Add hslua-module-path at version 0.1.0.1.
